@@ -44,13 +44,18 @@ class Ndex2(object):
     USER_AGENT_KEY = 'User-Agent'
     VALID_NETWORK_SYSTEM_PROPERTIES = ['showcase', 'visibility',
                                        'index_level', 'readOnly']
+    V3_ENDPOINT = '/v3'
 
     def __init__(self, host=None, username=None, password=None,
                  update_status=False, debug=False, user_agent='',
-                 timeout=30):
+                 timeout=30, skip_version_check=False):
         """
         Creates a connection to a particular `NDEx server <http://ndexbio.org>`_.
 
+
+        .. versionadded:: 3.5.0
+           *skip_version_check* parameter added
+
         :param host: The URL of the server.
         :type host: str
         :param username: The username of the NDEx account to use. (Optional)
@@ -68,9 +73,16 @@ class Ndex2(object):
                         is passed to Request calls `Click here for more information
                         <http://docs.python-requests.org/en/master/user/advanced/#timeouts>`_
         :type timeout: float or tuple(float, float)
+        :param skip_version_check: If ``True``, it is assumed
+                                   NDEx server supports **v2** endpoints,
+                                   otherwise NDEx server is queried to see
+                                   if **v2** endpoints are supported
+        :type skip_version_check: bool
+
         """
         self.debug = debug
-        self.version = 1.3
+        self.version = '1.3'
+        self.version_endpoint = '/rest'
         self.status = {}
         self.username = username
         self.password = password
@@ -92,46 +104,53 @@ class Ndex2(object):
         if "localhost" in host:
             self.host = "http://localhost:8080/ndexbio-rest"
         else:
-            status_url = "/rest/admin/status"
+            self.host = host
+            # Partial fix for https://github.com/ndexbio/ndex2-client/issues/85
+            # caller can now skip this check by setting skip_version_check to True
+            # in future this will be set to True by default
+            if skip_version_check is True:
+                self.version = '2.0'
+                self.version_endpoint = '/v2'
+            else:
+                status_url = "/rest/admin/status"
 
-            try:
-                version_url = urljoin(host, status_url)
+                try:
+                    version_url = urljoin(host, status_url)
 
-                response = requests.get(version_url,
-                                        headers={Ndex2.USER_AGENT_KEY:
-                                                 userAgent + self.user_agent})
-                response.raise_for_status()
-                data = response.json()
+                    response = requests.get(version_url,
+                                            headers={Ndex2.USER_AGENT_KEY:
+                                                     userAgent +
+                                                     self.user_agent})
+                    response.raise_for_status()
+                    data = response.json()
 
-                prop = data.get('properties')
-                if prop is not None:
-                    pv = prop.get('ServerVersion')
-                    if pv is not None:
-                        if not pv.startswith('2.'):
-                            raise Exception("This release only supports NDEx 2.x server.")
+                    prop = data.get('properties')
+                    if prop is not None:
+                        pv = prop.get('ServerVersion')
+                        if pv is not None:
+                            if not pv.startswith('2.'):
+                                raise Exception("This release only supports "
+                                                "NDEx 2.x server.")
+                            else:
+                                self.version = pv
+                                self.version_endpoint = '/v2'
                         else:
-                            self.version = pv
-                            self.host = host + "/v2"
+                            self.logger.warning("Warning: This release "
+                                                "doesn't fully "
+                                                "support 1.3 version of NDEx")
                     else:
-                        self.logger.warning("Warning: This release doesn't fully "
+                        self.logger.warning("Warning: No properties found. "
+                                            "This release doesn't fully "
                                             "support 1.3 version of NDEx")
-                        self.version = "1.3"
-                        self.host = host + "/rest"
-                else:
-                    self.logger.warning("Warning: No properties found. "
-                                        "This release doesn't fully "
-                                        "support 1.3 version of NDEx")
-                    self.version = "1.3"
-                    self.host = host + "/rest"
 
-            except req_except.HTTPError as he:
-                self.logger.warning("Can't determine server version. " + host +
-                                    ' Server returned error -- ' + str(he) +
-                                    ' will assume 1.3 version of NDEx which' +
-                                    ' is not fully supported by this release')
-                self.version = "1.3"
-                self.host = host + "/rest"
-                # TODO - how to handle errors getting server version...
+                except req_except.HTTPError as he:
+                    self.logger.warning("Can't determine server version. " +
+                                        host + ' Server returned error -- ' +
+                                        str(he) +
+                                        ' will assume 1.3 version of NDEx '
+                                        'which is not fully supported by this '
+                                        'release')
+                    # TODO - how to handle errors getting server version...
 
         # create a session for this Ndex
         self.s = requests.session()
@@ -228,6 +247,7 @@ class Ndex2(object):
         :raises NDExError: Raises this error unless
         :raises NDExNotFoundError: Raises this error if status code
                                    is 404
+        :raises NDExUnauthorizedError: Raises this error if status code is 401
         """
         if http_error is None:
             raise NDExError('Caught unknown server error')
@@ -235,6 +255,8 @@ class Ndex2(object):
                  ' from server: ' + str(http_error.response.text)
         if http_error.response.status_code == 404:
             raise NDExNotFoundError(errmsg)
+        if http_error.response.status_code == 401:
+            raise NDExUnauthorizedError(errmsg)
         raise NDExError(errmsg)
 
     def _convert_exception_to_ndex_error(self, error):
@@ -251,8 +273,15 @@ class Ndex2(object):
         raise NDExError('Caught ' + str(error.__class__.__name__) +
                         ': ' + str(error))
 
-    def put(self, route, put_json=None):
-        url = self.host + route
+    def _get_version_endpoint(self, alt_version_endpoint=None):
+        if alt_version_endpoint is None:
+            return self.version_endpoint
+        return alt_version_endpoint
+
+    def put(self, route, put_json=None, alt_version_endpoint=None):
+        url = self.host +\
+              self._get_version_endpoint(alt_version_endpoint=
+                                         alt_version_endpoint) + route
         self.logger.debug("PUT route: " + url)
         self.logger.debug("PUT json: " + str(put_json))
 
@@ -269,8 +298,10 @@ class Ndex2(object):
                                   timeout=self.timeout)
         return self._return_response(response)
 
-    def post(self, route, post_json):
-        url = self.host + route
+    def post(self, route, post_json, alt_version_endpoint=None):
+        url = self.host + \
+              self._get_version_endpoint(alt_version_endpoint=
+                                         alt_version_endpoint) + route
         self.logger.debug("POST route: " + url)
         self.logger.debug("POST json: " + post_json)
         headers = {'Content-Type': 'application/json',
@@ -285,8 +316,11 @@ class Ndex2(object):
     def delete(self, route, data=None,
                raiseforstatus=True,
                returnfullresponse=False,
-               returnjsonundertry=False):
-        url = self.host + route
+               returnjsonundertry=False,
+               alt_version_endpoint=None):
+        url = self.host + \
+              self._get_version_endpoint(alt_version_endpoint=
+                                         alt_version_endpoint) + route
         self.logger.debug("DELETE route: " + url)
         headers = self.s.headers
         headers[Ndex2.USER_AGENT_KEY] = userAgent + self.user_agent
@@ -302,8 +336,10 @@ class Ndex2(object):
                                      returnfullresponse=returnfullresponse,
                                      returnjsonundertry=returnjsonundertry)
 
-    def get(self, route, get_params=None):
-        url = self.host + route
+    def get(self, route, get_params=None, alt_version_endpoint=None):
+        url = self.host + \
+              self._get_version_endpoint(alt_version_endpoint=
+                                         alt_version_endpoint) + route
         self.logger.debug("GET route: " + url)
         headers = self.s.headers
         headers[Ndex2.USER_AGENT_KEY] = self._get_user_agent()
@@ -313,8 +349,10 @@ class Ndex2(object):
         return self._return_response(response)
 
     # The stream refers to the Response, not the Request
-    def get_stream(self, route, get_params=None):
-        url = self.host + route
+    def get_stream(self, route, get_params=None, alt_version_endpoint=None):
+        url = self.host + \
+              self._get_version_endpoint(alt_version_endpoint=
+                                         alt_version_endpoint) + route
         self.logger.debug("GET stream route: " + url)
         headers = self.s.headers
         headers[Ndex2.USER_AGENT_KEY] = self._get_user_agent()
@@ -324,8 +362,10 @@ class Ndex2(object):
                                      returnfullresponse=True)
 
     # The stream refers to the Response, not the Request
-    def post_stream(self, route, post_json):
-        url = self.host + route
+    def post_stream(self, route, post_json, alt_version_endpoint=None):
+        url = self.host + \
+              self._get_version_endpoint(alt_version_endpoint=
+                                         alt_version_endpoint) + route
         self.logger.debug("POST stream route: " + url)
         headers = self.s.headers
 
@@ -339,8 +379,11 @@ class Ndex2(object):
                                      returnfullresponse=True)
 
     # The Request is streamed, not the Response
-    def put_multipart(self, route, fields):
-        url = self.host + route
+    def put_multipart(self, route, fields, alt_version_endpoint=None,
+                      returnjsonundertry=True, returnfullresponse=False):
+        url = self.host + \
+              self._get_version_endpoint(alt_version_endpoint=
+                                         alt_version_endpoint) + route
         multipart_data = MultipartEncoder(fields=fields)
         self.logger.debug("PUT route: " + url)
 
@@ -351,14 +394,18 @@ class Ndex2(object):
                    }
         response = requests.put(url, data=multipart_data, headers=headers, auth=(self.username, self.password))
         return self._return_response(response,
-                                     returnjsonundertry=True)
+                                     returnjsonundertry=returnjsonundertry,
+                                     returnfullresponse=returnfullresponse)
 
     # The Request is streamed, not the Response
-    def post_multipart(self, route, fields, query_string=None):
+    def post_multipart(self, route, fields, query_string=None, alt_version_endpoint=None,
+                       returnjsonundertry=True, returnfullresponse=False):
+        url = self.host + \
+              self._get_version_endpoint(alt_version_endpoint=
+                                         alt_version_endpoint) + route
         if query_string:
-            url = self.host + route + '?' + query_string
-        else:
-            url = self.host + route
+            url = url + '?' + query_string
+
         multipart_data = MultipartEncoder(fields=fields)
         self.logger.debug("POST route: " + url)
         headers = {'Content-Type': multipart_data.content_type,
@@ -367,7 +414,8 @@ class Ndex2(object):
                    }
         response = requests.post(url, data=multipart_data, headers=headers, auth=(self.username, self.password))
         return self._return_response(response,
-                                     returnjsonundertry=True)
+                                     returnjsonundertry=returnjsonundertry,
+                                     returnfullresponse=returnfullresponse)
 
 # Network methods
 
@@ -434,9 +482,123 @@ class Ndex2(object):
 
         return self.post_multipart(route, fields, query_string=query_string)
 
+    def save_new_cx2_network(self, cx, visibility=None):
+        """
+        Create a new network (CX2) on the server
+
+        .. versionadded:: 3.5.0
+
+        .. code-block:: python
+
+            from ndex2.client import Ndex2
+            from ndex2.exceptions import NDExError
+
+            client = Ndex2(username=<NDEx USER NAME>,
+                           password=<NDEx PASSWORD>,
+                           skip_version_check=True)
+
+            # cx is set to an empty CX2 network
+            cx = [{"CXVersion":"2.0","hasFragments":false},
+                  {"status":[{"success":true}]}]
+
+            try:
+                net_url = client.save_new_cx2_network(cx, visibility='PRIVATE')
+                print('URL of new network: ' + str(net_url))
+            except NDExError as ne:
+                print('Caught error: ' + str(ne))
+
+        :param cx: Network CX2 which is a list of dict objects
+        :type cx: list
+        :param visibility: Sets the visibility (PUBLIC or PRIVATE)
+                           If ``None`` sets visibility to PRIVATE
+        :type visibility: str
+        :raises NDExUnauthorizedError: If credentials are invalid or not set
+        :raises NDExInvalidCXError: if **cx** is ``None``, not a list,
+                                    or is an empty list
+        :raises NDExError: if there is an error saving the network
+        :return: Full URL to newly created network
+                 (ie http://ndexbio.org/v3/networks/XXXX)
+        :rtype: str
+        """
+        if cx is None:
+            raise NDExInvalidCXError('CX is None')
+        if not isinstance(cx, list):
+            raise NDExInvalidCXError('CX is not a list')
+        if len(cx) is 0:
+            raise NDExInvalidCXError('CX appears to be empty')
+
+        if sys.version_info.major == 3:
+            stream = io.BytesIO(json.dumps(cx, cls=DecimalEncoder).encode('utf-8'))
+        else:
+            stream = io.BytesIO(json.dumps(cx, cls=DecimalEncoder))
+
+        return self.save_cx2_stream_as_new_network(stream, visibility=visibility)
+
+    def save_cx2_stream_as_new_network(self, cx_stream, visibility=None):
+        """
+        Create a new network from a CX2 stream
+
+        .. versionadded:: 3.5.0
+
+        .. code-block:: python
+
+            import io
+            import json
+            from ndex2.client import Ndex2
+            from ndex2.exceptions import NDExError
+
+            client = Ndex2(username=<NDEx USER NAME>,
+                           password=<NDEx PASSWORD>,
+                           skip_version_check=True)
+
+            # cx is set to an empty CX2 network
+            cx = [{"CXVersion":"2.0","hasFragments":false},
+                  {"status":[{"success":true}]}]
+
+            try:
+                cx_stream = io.BytesIO(json.dumps(cx,
+                                                  cls=DecimalEncoder).encode('utf-8'))
+                net_url = client.save_cx2_stream_as_new_network(cx_stream,
+                                                                visibility='PUBLIC')
+                print('Network URL: ' + str(net_url))
+            except NDExError as ne:
+                print('Caught error: ' + str(ne))
+
+        :param cx_stream:  IO stream of cx2
+        :type cx_stream: BytesIO like object
+        :param visibility: Sets the visibility (PUBLIC or PRIVATE)
+        :type visibility: str
+        :raises NDExUnauthorizedError: If credentials are invalid or not set
+        :raises NDExError: if there is an error saving the network
+        :return: Full URL to newly created network
+                 (ie http://ndexbio.org/v3/networks/XXXX)
+        :rtype: str
+        """
+        self._require_auth()
+        query_string = None
+        if visibility:
+            query_string = 'visibility=' + str(visibility)
+
+        fields = {
+            'CXNetworkStream': ('filename', cx_stream, 'application/octet-stream')
+        }
+        try:
+            res = self.post_multipart('/networks', fields, query_string=query_string,
+                                      alt_version_endpoint=Ndex2.V3_ENDPOINT,
+                                      returnfullresponse=True)
+            if 'Location' not in res.headers:
+                raise NDExError('Unable to get URL for newly created network: ' +
+                                str(res.text))
+            return res.headers['Location']
+        except requests.HTTPError as he:
+            self._convert_requests_http_error_to_ndex_error(he)
+        except Exception as e:
+            self._convert_exception_to_ndex_error(e)
+
     def update_cx_network(self, cx_stream, network_id):
         """
-        Update the network specified by UUID network_id using the CX stream cx_stream.
+        Update the network specified by UUID network_id using the CX stream
+        **cx_stream** passed in
 
         :param cx_stream: The network stream.
         :param network_id: The UUID of the network.
@@ -458,6 +620,59 @@ class Ndex2(object):
 
         return self.put_multipart(route, fields)
 
+    def update_cx2_network(self, cx_stream, network_id):
+        """
+        Update the network specified by UUID network_id using the CX2
+        stream **cx_stream** passed in
+
+        .. versionadded:: 3.5.0
+
+        .. code-block:: python
+
+            import io
+            import json
+            from ndex2.client import Ndex2
+            from ndex2.exceptions import NDExError
+
+            client = Ndex2(username=<NDEx USER NAME>,
+                           password=<NDEx PASSWORD>,
+                           skip_version_check=True)
+
+            # cx is set to an empty CX2 network
+            cx = [{"CXVersion":"2.0","hasFragments":false},
+                  {"status":[{"success":true}]}]
+
+            try:
+                cx_stream = io.BytesIO(json.dumps(cx,
+                                                  cls=DecimalEncoder).encode('utf-8'))
+                client.update_cx2_network(cx_stream, <UUID OF NETWORK TO UPDATE>)
+                print('Success')
+            except NDExError as ne:
+                print('Caught error: ' + str(ne))
+
+
+        :param cx_stream: The network stream.
+        :param network_id: The UUID of the network.
+        :type network_id: str
+        :raises NDExUnauthorizedError: If credentials are invalid or not set
+        :raises NDExError: If there is an error updating the network
+        :return: Nothing is returned. To check status
+                 call :py:func:`get_network_summary`
+        """
+        self._require_auth()
+        fields = {
+            'CXNetworkStream': ('filename', cx_stream, 'application/octet-stream')
+        }
+
+        try:
+            # update endpoint has no output so do not return anything
+            self.put_multipart('/networks/' + str(network_id), fields,
+                               alt_version_endpoint=Ndex2.V3_ENDPOINT)
+        except requests.HTTPError as he:
+            self._convert_requests_http_error_to_ndex_error(he)
+        except Exception as e:
+            self._convert_exception_to_ndex_error(e)
+
     def get_network_as_cx_stream(self, network_id):
         """
         Get the existing network with UUID network_id from the NDEx connection as a CX stream.
@@ -476,6 +691,57 @@ class Ndex2(object):
 
         return self.get_stream(route)
 
+    def get_network_as_cx2_stream(self, network_id, access_key=None):
+        """
+        Get the existing network with UUID network_id from the NDEx connection as CX2 stream
+        contained within a :py:class:`requests.Response` object
+
+        .. versionadded:: 3.5.0
+
+        Example usage:
+
+        .. code-block:: python
+
+            from ndex2.client import Ndex2
+            client = Ndex2(skip_version_check=True)
+
+            # 7fc.. is UUID MuSIC v1 network: http://doi.org/10.1038/s41586-021-04115-9
+            client_resp = client.get_network_as_cx2_stream('7fc70ab6-9fb1-11ea-aaef-0ac135e8bacf')
+
+            # for HTTP status code, 200 means success
+            print(client_resp.status_code)
+
+            # for smaller networks one can get the CX2 by calling:
+            print(client_resp.json())
+
+
+        .. note::
+
+            For retrieving larger networks see :py:meth:`requests.Response.iter_content`
+
+            This method sets `stream=True` in the request to
+            avoid loading response into memory.
+
+
+        :param network_id: The UUID of the network
+        :param access_key: Optional access key UUID
+        :raises NDExError: If there was an error
+        :return: Requests library response with CX2 in content and status
+                 code of 200 upon success
+        :rtype: :py:class:`requests.Response`
+        """
+        get_params = None
+        if access_key is not None:
+            get_params = {'accesskey': str(access_key)}
+        try:
+            return self.get_stream('/networks/' + str(network_id),
+                                   get_params=get_params,
+                                   alt_version_endpoint=Ndex2.V3_ENDPOINT)
+        except requests.HTTPError as he:
+            self._convert_requests_http_error_to_ndex_error(he)
+        except Exception as e:
+            self._convert_exception_to_ndex_error(e)
+
     def get_network_aspect_as_cx_stream(self, network_id, aspect_name):
         """
         Get the specified aspect of the existing network with UUID network_id from the NDEx connection as a CX stream.
@@ -498,6 +764,71 @@ class Ndex2(object):
 
         return self.get_stream(route)
 
+    def get_network_aspect_as_cx2_stream(self, network_id, aspect_name=None,
+                                         access_key=None, size=None):
+        """
+        Gets JSON array of CX2 elements from the aspect specified by **aspect_name** from the
+        network specified by **network_id**
+
+        .. versionadded:: 3.5.0
+
+        Example usage:
+
+        .. code-block:: python
+
+            from ndex2.client import Ndex2
+            client = Ndex2(skip_version_check=True)
+
+            # 7fc.. is UUID MuSIC v1 network: http://doi.org/10.1038/s41586-021-04115-9
+            client_resp = client.get_network_aspect_as_cx2_stream('7fc70ab6-9fb1-11ea-aaef-0ac135e8bacf', 'nodes')
+
+            # for HTTP status code, 200 means success
+            print(client_resp.status_code)
+
+            # for smaller networks one can get the CX2 by calling:
+            print(client_resp.json())
+
+
+        .. note::
+
+            For retrieving larger networks see :py:meth:`requests.Response.iter_content`
+
+            This method sets `stream=True` in the request to
+            avoid loading response into memory.
+
+
+        :param network_id: The UUID of the network
+        :type network_id: str
+        :param aspect_name: Name of CX2 aspect.
+                            Example aspects: ``nodes``, ``edges``,
+                                             ``networkAttributes`` etc.
+        :type aspect_name: str
+        :param access_key: Optional access key UUID
+        :param size: Denotes number of elements of given aspect to return. If < 0 or
+                     ``None`` all elements will be returned
+        :type size: int
+        :raises NDExError: If there was an error
+        :return: Requests library response with CX2 in content and status
+                 code of 200 upon success
+        :rtype: :py:class:`requests.Response`
+        """
+        get_params = None
+        if access_key is not None:
+            get_params = {'accesskey': str(access_key)}
+        if size is not None:
+            if get_params is None:
+                get_params = {}
+            get_params['size'] = size
+        try:
+            return self.get_stream('/networks/' + str(network_id) +
+                                   '/aspects/' + str(aspect_name),
+                                   get_params=get_params,
+                                   alt_version_endpoint=Ndex2.V3_ENDPOINT)
+        except requests.HTTPError as he:
+            self._convert_requests_http_error_to_ndex_error(he)
+        except Exception as e:
+            self._convert_exception_to_ndex_error(e)
+
     def get_neighborhood_as_cx_stream(self, network_id, search_string, search_depth=1, edge_limit=2500, error_when_limit=True):
         """
         Get a CX stream for a subnetwork of the network specified by UUID network_id and a traversal of search_depth
@@ -691,11 +1022,92 @@ class Ndex2(object):
 
     def get_network_summary(self, network_id):
         """
-        Gets information about a network.
+        Gets information and status of a network
 
-        :param network_id: The UUID of the network.
+        Example usage:
+
+        .. code-block:: python
+
+            from ndex2.client import Ndex2
+            client = Ndex2(skip_version_check=True)
+
+            # 7fc.. is UUID MuSIC v1 network: http://doi.org/10.1038/s41586-021-04115-9
+            net_sum = client.get_network_summary('7fc70ab6-9fb1-11ea-aaef-0ac135e8bacf')
+
+            print(net_sum)
+
+
+        Example result:
+
+        .. code-block:: text
+
+            {
+              "ownerUUID": "daa09f36-8cdd-11e7-a10d-0ac135e8bacf",
+              "isReadOnly": true,
+              "subnetworkIds": [],
+              "isValid": true,
+              "warnings": [],
+              "isShowcase": true,
+              "doi": "10.18119/N9188W",
+              "isCertified": true,
+              "indexLevel": "ALL",
+              "hasLayout": true,
+              "hasSample": false,
+              "cxFileSize": 82656,
+              "cx2FileSize": 68979,
+              "visibility": "PUBLIC",
+              "nodeCount": 70,
+              "edgeCount": 87,
+              "completed": true,
+              "version": "1.0",
+              "owner": "yue",
+              "description": "<div><br/></div><div>Two central approaches for mapping cellular structure \u2013 protein fluorescent imaging and protein biophysical association \u2013 each generate extensive datasets but of distinct qualities and resolutions that are typically treated separately. The MuSIC map is designed to address this challenge, by integrating immunofluorescent images in the Human Protein Atlas with ongoing affinity purification experiments from the BioPlex resource. The result is a unified hierarchical map of eukaryotic cell architecture. In the MuSIC hierarchy, nodes represent systems and arrows indicate containment of the lower system by the upper. Node color indicates known (gold) or putative novel (purple) systems. The size of each circle is based on the number of proteins in the system. The relative height of each system in the layout is determined based on the predicted diameter of the system in MuSIC.<br/></div>",
+              "name": "Multi-Scale Integrated Cell (MuSIC) v1",
+              "properties": [
+                {
+                  "subNetworkId": null,
+                  "predicateString": "author",
+                  "dataType": "string",
+                  "value": "Yue Qin"
+                },
+                {
+                  "subNetworkId": null,
+                  "predicateString": "rights",
+                  "dataType": "string",
+                  "value": "MIT license (MIT)"
+                },
+                {
+                  "subNetworkId": null,
+                  "predicateString": "rightsHolder",
+                  "dataType": "string",
+                  "value": "Yue Qin"
+                },
+                {
+                  "subNetworkId": null,
+                  "predicateString": "reference",
+                  "dataType": "string",
+                  "value": "Yue Qin, Edward L. Huttlin, Casper F. Winsnes, Maya L. Gosztyla, Ludivine Wacheul, Marcus R. Kelly, Steven M. Blue, Fan Zheng, Michael Chen, Leah V. Schaffer, Katherine Licon, Anna B\u00e4ckstr\u00f6m, Laura Pontano Vaites, John J. Lee, Wei Ouyang, Sophie N. Liu, Tian Zhang, Erica Silva, Jisoo Park, Adriana Pitea, Jason F. Kreisberg, Steven P. Gygi, Jianzhu Ma, J. Wade Harper, Gene W. Yeo, Denis L. J. Lafontaine, Emma Lundberg, Trey Ideker<br><strong>A multi-scale map of cell structure fusing protein images and interactions</strong><br><i>Nature 600, 536\u2013542 (2021).</i>, (2021)<br><a href=\"http://doi.org/10.1038/s41586-021-04115-9\"  target=\"_blank\">10.1038/s41586-021-04115-9</a>"
+                }
+              ],
+              "externalId": "7fc70ab6-9fb1-11ea-aaef-0ac135e8bacf",
+              "isDeleted": false,
+              "modificationTime": 1630270298717,
+              "creationTime": 1590539529001
+            }
+
+        .. note::
+
+            **isvalid** is a boolean to denote that the network was inspected, not
+            that it is actually valid.
+
+            **errorMessage** Will be in result if there was an error parsing network
+
+            **completed** is set to ``True`` after all server tasks have completed and
+            network is ready to be used
+
+        :param network_id: The UUID of the network
         :type network_id: str
-        :return: Summary
+        :return: Summary information about network
         :rtype: dict
 
         """
