@@ -1,9 +1,6 @@
 __author__ = 'aarongary'
 
 import logging
-import json
-import ijson
-import requests
 import base64
 import sys
 import math
@@ -59,7 +56,8 @@ class NiceCXBuilder(object):
 
     def set_context(self, context):
         """
-        Set the @context information of the network.  This information maps namespace prefixes to their defining URIs
+        Set the @context information of the network.  This information
+        maps namespace prefixes to their defining URIs
 
         Example:
 
@@ -101,7 +99,6 @@ class NiceCXBuilder(object):
         :return: None
         :rtype: None
         """
-
         add_this_network_attribute = {'n': name, 'v': values}
         if type:
             add_this_network_attribute['d'] = type
@@ -209,7 +206,6 @@ class NiceCXBuilder(object):
 
         add_this_node_attribute = {'po': property_of, 'n': name, 'v': values}
 
-
         if self.node_attribute_map.get(property_of) is None:
             self.node_attribute_map[property_of] = {}
         elif self.node_attribute_map[property_of].get(name) is not None:
@@ -441,45 +437,24 @@ class NiceCXBuilder(object):
 
         return return_list
 
-    def load_aspect(self, aspect_name):
-        #with open('Signal1.cx', mode='r') as cx_f:
-        with open('network1.cx', mode='r') as cx_f:
-            aspect_json = json.loads(cx_f.read())
-            for aspect in aspect_json:
-                if aspect.get(aspect_name) is not None:
-                    return aspect.get(aspect_name)
-
-    def stream_all_aspects(self, uuid):
-        return ijson.items(urlopen('http://dev2.ndexbio.org/v2/network/' + uuid), 'item')
-
-    def stream_aspect(self, uuid, aspect_name):
-        if aspect_name == 'metaData':
-            self.logger.debug('http://dev2.ndexbio.org/v2/network/' + str(uuid) + '/aspect')
-            md_response = requests.get('http://dev2.ndexbio.org/v2/network/' + uuid + '/aspect')
-            json_respone = md_response.json()
-            return json_respone.get('metaData')
-        else:
-            request = Request('http://dev2.ndexbio.org/v2/network/' + uuid + '/aspect/' + aspect_name)
-            base64string = base64.b64encode('%s:%s' % ('scratch', 'scratch'))
-            request.add_header("Authorization", "Basic %s" % base64string)
-            #result = urllib2.urlopen(request)
-            urlopen_result = None
-            try:
-                urlopen_result = urlopen(request) #'http://dev2.ndexbio.org/v2/network/' + uuid + '/aspect/' + aspect_name)
-            except HTTPError as e:
-                self.logger.error(str(e.code))
-                return []
-            except URLError as e:
-                self.logger.error('Other error')
-                self.logger.error('URL Error ' + str(e.message()))
-                return []
-
-            return ijson.items(urlopen_result, 'item')
-
-    def stream_aspect_raw(self, uuid, aspect_name):
-        return ijson.parse(urlopen('http://dev2.ndexbio.org/v2/network/' + uuid + '/aspect/' + aspect_name))
-
     def _infer_data_type(self, val, split_string=False):
+        """
+        Gets data type of **val** and returns an updated **val** value
+        that conforms to the data type inferred
+
+        Okay this is kinda complicated, but this code leverages :python:`isinstance`
+        to determine data types
+
+
+        :param val: Value to infer data type from
+        :param split_string: If ``True`` split **val** if it is type :py:func:`str`
+                             and it contains ``,`` or ``;``. Order matters if both
+                             ``,`` and ``;`` are found **val** is split by ``,``
+        :type split_string: bool
+        :return: (processed value, CX data type), if **val** is ``None`` then ``(None, None)`` is
+                 returned
+        :rtype tuple
+        """
         if val is None:
             return None, None
 
@@ -493,26 +468,33 @@ class NiceCXBuilder(object):
                 elif ';' in val:
                     val = val.split(';')
 
-        processed_value = val
-
         if isinstance(val, float) or isinstance(val, np.float) or isinstance(val, np.double):
             if math.isnan(val):
                 # do something (skip?)
-                processed_value = None
+                val = None
             elif math.isinf(val):
-                processed_value = 'INFINITY'
-            attr_type = 'double'  # CX spec dropped support for float and instead uses double precision
-        elif isinstance(val, int) or isinstance(val, np.int):
-            attr_type = 'integer'
-        elif isinstance(val, list):
+                val = 'INFINITY'
+            return val, 'double'
+        if isinstance(val, bool):
+            # fix for https://github.com/ndexbio/ndex2-client/issues/83
+            # a boolean is a sub type of int so bool must be tested first
+            return val, 'boolean'
+        if isinstance(val, int) or isinstance(val, np.int):
+            return val, 'integer'
+        if isinstance(val, list):
+            # if the list is empty just set data type to list_of_string
+            # fix for https://github.com/ndexbio/ndex2-client/issues/90
+            attr_type = 'list_of_string'
             if len(val) > 0:
                 if isinstance(val[0], float) or isinstance(val[0], np.float) or isinstance(val[0], np.double):
                     attr_type = 'list_of_double'
+                elif isinstance(val[0], bool):
+                    # fix for https://github.com/ndexbio/ndex2-client/issues/83
+                    # a boolean is a sub type of int so bool must be tested first
+                    attr_type = 'list_of_boolean'
                 elif isinstance(val[0], int) or isinstance(val[0], np.int):
                     attr_type = 'list_of_integer'
-                else:
-                    attr_type = 'list_of_string'
 
-        return processed_value, attr_type
+        return val, attr_type
 
 
