@@ -25,7 +25,7 @@ from ndex2.exceptions import NDExInvalidParameterError
 from ndex2.exceptions import NDExUnsupportedCallError
 from ndex2.exceptions import NDExError
 
-SKIP_REASON = 'NDEX2_TEST_USER environment variable detected, ' \
+SKIP_REASON = 'NDEX2_TEST_SERVER environment variable detected, ' \
               'skipping for integration tests'
 
 
@@ -84,7 +84,7 @@ class TestClient(unittest.TestCase):
         # try with nothing set
         ndex = Ndex2(host='localhost')
         self.assertEqual(ndex.debug, False)
-        self.assertEqual(ndex.version, 1.3)
+        self.assertEqual(ndex.version, '1.3')
         self.assertEqual(ndex.status, {})
         self.assertEqual(ndex.username, None)
         self.assertEqual(ndex.password, None)
@@ -101,11 +101,12 @@ class TestClient(unittest.TestCase):
                      password='smith', user_agent='yo', debug=True,
                      timeout=1)
         self.assertEqual(ndex.debug, True)
-        self.assertEqual(ndex.version, 1.3)
+        self.assertEqual(ndex.version, '1.3')
         self.assertEqual(ndex.status, {})
         self.assertEqual(ndex.username, 'bob')
         self.assertEqual(ndex.password, 'smith')
         self.assertEqual(ndex.user_agent, ' yo')
+        self.assertEqual(ndex.version_endpoint, '/rest')
         self.assertEqual(ndex.host, 'http://localhost:8080/ndexbio-rest')
         self.assertTrue(ndex.s is not None)
         self.assertTrue(ndex.timeout, 1)
@@ -130,7 +131,8 @@ class TestClient(unittest.TestCase):
             self.assertEqual(ndex.username, None)
             self.assertEqual(ndex.password, None)
             self.assertEqual(ndex.user_agent, '')
-            self.assertEqual(ndex.host, client.DEFAULT_SERVER + '/rest')
+            self.assertEqual(ndex.version_endpoint, '/rest')
+            self.assertEqual(ndex.host, client.DEFAULT_SERVER)
             self.assertTrue(ndex.s is not None)
 
     def test_ndex2_constructor_with_defaulthost_serverversionnone(self):
@@ -148,7 +150,8 @@ class TestClient(unittest.TestCase):
             self.assertEqual(ndex.username, None)
             self.assertEqual(ndex.password, None)
             self.assertEqual(ndex.user_agent, '')
-            self.assertEqual(ndex.host, client.DEFAULT_SERVER + '/rest')
+            self.assertEqual(ndex.version_endpoint, '/rest')
+            self.assertEqual(ndex.host, client.DEFAULT_SERVER)
             self.assertTrue(ndex.s is not None)
 
     def test_ndex2_constructor_with_defaulthost_properties_is_none(self):
@@ -165,7 +168,8 @@ class TestClient(unittest.TestCase):
             self.assertEqual(ndex.username, None)
             self.assertEqual(ndex.password, None)
             self.assertEqual(ndex.user_agent, '')
-            self.assertEqual(ndex.host, client.DEFAULT_SERVER + '/rest')
+            self.assertEqual(ndex.version_endpoint, '/rest')
+            self.assertEqual(ndex.host, client.DEFAULT_SERVER)
             self.assertTrue(ndex.s is not None)
 
     def test_ndex2_constructor_with_defaulthost_thatisversionone(self):
@@ -195,9 +199,22 @@ class TestClient(unittest.TestCase):
             self.assertEqual(ndex.username, None)
             self.assertEqual(ndex.password, None)
             self.assertEqual(ndex.user_agent, '')
-            self.assertEqual(ndex.host, client.DEFAULT_SERVER + '/v2')
+            self.assertEqual(ndex.version_endpoint, '/v2')
+            self.assertEqual(ndex.host, client.DEFAULT_SERVER)
             self.assertTrue(ndex.s is not None)
 
+    def test_ndex2_constructor_with_skip_check_version_true(self):
+        ndex = Ndex2(skip_version_check=True)
+        self.assertEqual(ndex.debug, False)
+        self.assertEqual(ndex.version, '2.0')
+        self.assertEqual(ndex.status, {})
+        self.assertEqual(ndex.username, None)
+        self.assertEqual(ndex.password, None)
+        self.assertEqual(ndex.user_agent, '')
+        self.assertEqual(ndex.version_endpoint, '/v2')
+        self.assertEqual(ndex.host, client.DEFAULT_SERVER)
+        self.assertTrue(ndex.s is not None)
+
     def test_ndex2_require_auth(self):
         ndex = Ndex2(host='localhost')
         try:
@@ -867,6 +884,96 @@ class TestClient(unittest.TestCase):
             self.assertTrue('"error": ""' in decode_txt)
             self.assertTrue('"success": true' in decode_txt)
 
+    def test_save_new_cx2_network_none_as_cx(self):
+        ndex = Ndex2(skip_version_check=True)
+        try:
+            ndex.save_new_cx2_network(None)
+            self.fail('expected NDExInvalidCXError')
+        except NDExInvalidCXError as ice:
+            self.assertEqual(str(ice), 'CX is None')
+
+    def test_save_new_cx2_network_invalid_as_cx(self):
+        ndex = Ndex2(skip_version_check=True)
+        try:
+            ndex.save_new_cx2_network('hi')
+            self.fail('expected NDExInvalidCXError')
+        except NDExInvalidCXError as ice:
+            self.assertEqual(str(ice), 'CX is not a list')
+
+    def test_save_new_cx2_network_empty_cx(self):
+        ndex = Ndex2(skip_version_check=True)
+        try:
+            ndex.save_new_cx2_network([])
+            self.fail('expected NDExInvalidCXError')
+        except NDExInvalidCXError as ice:
+            self.assertEqual(str(ice), 'CX appears to be empty')
+
+    def test_save_new_cx2_network_with_no_location_in_header(self):
+        with requests_mock.mock() as m:
+            resurl = client.DEFAULT_SERVER + '/v3/networks/asdf'
+            m.post(client.DEFAULT_SERVER + '/v3/networks',
+                   request_headers={'Connection': 'close'},
+                   status_code=1,
+                   text=resurl)
+            ndex = Ndex2(username='bob', password='warnerbrandis',
+                         skip_version_check=True)
+            try:
+                ndex.save_new_cx2_network([{'foo': '123'}])
+                self.fail('Expected Exception')
+            except NDExError as ne:
+                self.assertTrue('Unable to get URL for newly' in str(ne))
+
+    def test_save_new_cx2_network_with_server_error(self):
+        with requests_mock.mock() as m:
+            resurl = client.DEFAULT_SERVER + '/v3/networks/asdf'
+            m.post(client.DEFAULT_SERVER + '/v3/networks',
+                   request_headers={'Connection': 'close'},
+                   json={'error': 'bad'},
+                   status_code=500)
+            ndex = Ndex2(username='bob', password='warnerbrandis',
+                         skip_version_check=True)
+            try:
+                ndex.save_new_cx2_network([{'foo': '123'}],
+                                          visibility='PUBLIC')
+                self.fail('Expected Exception')
+            except NDExError as ne:
+                self.assertEqual('Caught 500 from server: '
+                                 '{"error": "bad"}', str(ne))
+
+    def test_save_new_cx2_network_with_visibility(self):
+        with requests_mock.mock() as m:
+            resurl = client.DEFAULT_SERVER + '/v3/networks/asdf'
+            m.post(client.DEFAULT_SERVER + '/v3/networks?visibility=PUBLIC',
+                   request_headers={'Connection': 'close'},
+                   headers={'Location': resurl},
+                   status_code=202)
+            ndex = Ndex2(username='bob', password='warnerbrandis',
+                         skip_version_check=True)
+            res = ndex.save_new_cx2_network([{'foo': '123'}],
+                                            visibility='PUBLIC')
+            self.assertEqual(res, resurl)
+            decode_txt = m.last_request.text.read().decode('UTF-8')
+            self.assertTrue('Content-Disposition: form-data; '
+                            'name="CXNetworkStream"; '
+                            'filename="filename"' in decode_txt)
+            self.assertTrue('Content-Type: application/'
+                            'octet-stream' in decode_txt)
+            self.assertTrue('{"foo": "123"}' in decode_txt)
+
+    def test_save_new_cx2_network_with_nourl(self):
+        with requests_mock.mock() as m:
+            m.post(client.DEFAULT_SERVER + '/v3/networks',
+                   request_headers={'Connection': 'close'},
+                   status_code=202)
+            ndex = Ndex2(username='bob', password='warnerbrandis',
+                         skip_version_check=True)
+            try:
+                ndex.save_new_cx2_network([{'foo': '123'}])
+                self.fail('Expected Exception')
+            except NDExError as ne:
+                self.assertTrue('Unable to get URL for newly '
+                                'created network' in str(ne))
+
     def test_update_cx_network_success(self):
         with requests_mock.mock() as m:
             resurl = client.DEFAULT_SERVER + '/v2/network/asdf'
@@ -931,6 +1038,89 @@ class TestClient(unittest.TestCase):
             self.assertTrue('"error": ""' in decode_txt)
             self.assertTrue('"success": true' in decode_txt)
 
+    def test_update_cx2_network_success(self):
+        with requests_mock.mock() as m:
+
+            m.put(client.DEFAULT_SERVER + '/v3/networks/someid',
+                  request_headers={'Connection': 'close'},
+                  status_code=200)
+            ndex = Ndex2(username='bob', password='warnerbrandis',
+                         skip_version_check=True)
+            cx = [{'foo': '123'},
+                  {"status": [{"error": "", "success": True}]}]
+
+            if sys.version_info.major == 3:
+                stream = io.BytesIO(json.dumps(cx,
+                                               cls=DecimalEncoder)
+                                    .encode('utf-8'))
+            else:
+                stream = io.BytesIO(json.dumps(cx, cls=DecimalEncoder))
+
+            ndex.update_cx2_network(stream, 'someid')
+
+            decode_txt = m.last_request.text.read().decode('UTF-8')
+            self.assertTrue('Content-Disposition: form-data; '
+                            'name="CXNetworkStream"; '
+                            'filename="filename"' in decode_txt)
+            self.assertTrue('Content-Type: application/'
+                            'octet-stream' in decode_txt)
+            self.assertTrue('{"foo": "123"}' in decode_txt)
+            self.assertTrue('{"status": [{"' in decode_txt)
+            self.assertTrue('"error": ""' in decode_txt)
+            self.assertTrue('"success": true' in decode_txt)
+
+    def test_update_cx2_network_server_error(self):
+        with requests_mock.mock() as m:
+
+            m.put(client.DEFAULT_SERVER + '/v3/networks/someid',
+                  request_headers={'Connection': 'close'},
+                  json={'error': 'bad'},
+                  status_code=500)
+            ndex = Ndex2(username='bob', password='warnerbrandis',
+                         skip_version_check=True)
+            cx = [{'foo': '123'},
+                  {"status": [{"error": "", "success": True}]}]
+
+            if sys.version_info.major == 3:
+                stream = io.BytesIO(json.dumps(cx,
+                                               cls=DecimalEncoder)
+                                    .encode('utf-8'))
+            else:
+                stream = io.BytesIO(json.dumps(cx, cls=DecimalEncoder))
+
+            try:
+                ndex.update_cx2_network(stream, 'someid')
+                self.fail('Expected exception')
+            except NDExError as ne:
+                self.assertEqual('Caught 500 from server: '
+                                 '{"error": "bad"}', str(ne))
+
+    def test_update_cx2_network_other_error(self):
+        with requests_mock.mock() as m:
+
+            m.put(client.DEFAULT_SERVER + '/v3/networks/someid',
+                  request_headers={'Connection': 'close'},
+                  json={'error': 'bad'},
+                  status_code=500)
+            ndex = Ndex2(username='bob', password='warnerbrandis',
+                         skip_version_check=True)
+            ndex.host = None
+            cx = [{'foo': '123'},
+                  {"status": [{"error": "", "success": True}]}]
+
+            if sys.version_info.major == 3:
+                stream = io.BytesIO(json.dumps(cx,
+                                               cls=DecimalEncoder)
+                                    .encode('utf-8'))
+            else:
+                stream = io.BytesIO(json.dumps(cx, cls=DecimalEncoder))
+
+            try:
+                ndex.update_cx2_network(stream, 'someid')
+                self.fail('Expected exception')
+            except NDExError as ne:
+                self.assertTrue('Caught TypeError' in str(ne))
+
     def test_validate_network_system_properties(self):
         with requests_mock.mock() as m:
             m.get(self.get_rest_admin_status_url(),
@@ -1336,6 +1526,143 @@ class TestClient(unittest.TestCase):
             self.assertEqual(res.json(), {'hi': 'bye'})
             self.assertEqual(res.status_code, 200)
 
+    def test_get_network_aspect_as_cx2_stream_success(self):
+        with requests_mock.mock() as m:
+            m.get(client.DEFAULT_SERVER + '/v3/networks/someid/aspects/sa',
+                  status_code=200,
+                  json={'hi': 'bye'},
+                  headers={'Content-Type': 'application/json'})
+            ndex = Ndex2(skip_version_check=True)
+            ndex.set_debug_mode(True)
+            res = ndex.get_network_aspect_as_cx2_stream('someid',
+                                                        aspect_name='sa')
+            self.assertEqual(res.json(), {'hi': 'bye'})
+            self.assertEqual(res.status_code, 200)
+
+    def test_get_network_aspect_as_cx2_stream_success_with_size(self):
+        with requests_mock.mock() as m:
+            m.get(client.DEFAULT_SERVER + '/v3/networks/someid/'
+                                          'aspects/sa?size=4',
+                  status_code=200,
+                  json={'hi': 'bye'},
+                  headers={'Content-Type': 'application/json'})
+            ndex = Ndex2(skip_version_check=True)
+            ndex.set_debug_mode(True)
+            res = ndex.get_network_aspect_as_cx2_stream('someid',
+                                                        aspect_name='sa',
+                                                        size=4)
+            self.assertEqual(res.json(), {'hi': 'bye'})
+            self.assertEqual(res.status_code, 200)
+
+    def test_get_network_aspect_as_cx2_stream_success_with_size_access(self):
+        with requests_mock.mock() as m:
+            m.get(client.DEFAULT_SERVER + '/v3/networks/someid/'
+                                          'aspects/sa?accesskey=key&size=4',
+                  status_code=200,
+                  json={'hi': 'bye'},
+                  headers={'Content-Type': 'application/json'})
+            ndex = Ndex2(skip_version_check=True)
+            ndex.set_debug_mode(True)
+            res = ndex.get_network_aspect_as_cx2_stream('someid',
+                                                        aspect_name='sa',
+                                                        access_key='key',
+                                                        size=4)
+            self.assertEqual(res.json(), {'hi': 'bye'})
+            self.assertEqual(res.status_code, 200)
+
+    def test_get_network_aspect_as_cx2_stream_error(self):
+        with requests_mock.mock() as m:
+            m.get(client.DEFAULT_SERVER + '/v3/networks/someid/aspects/sa',
+                  status_code=500,
+                  json={'hi': 'bye'},
+                  headers={'Content-Type': 'application/json'})
+            ndex = Ndex2(skip_version_check=True)
+            ndex.set_debug_mode(True)
+            try:
+                ndex.get_network_aspect_as_cx2_stream('someid',
+                                                      aspect_name='sa')
+                self.fail('Expected exception')
+            except NDExError as ne:
+                self.assertEqual('Caught 500 from server: {"hi": "bye"}',
+                                 str(ne))
+
+    def test_get_network_aspect_as_cx2_stream_low_level_error(self):
+        with requests_mock.mock() as m:
+            m.get(client.DEFAULT_SERVER + '/v3/networks/someid/aspects/sa',
+                  status_code=200,
+                  json={'error': 'bye'},
+                  headers={'Content-Type': 'application/json'})
+            ndex = Ndex2(skip_version_check=True)
+            ndex.set_debug_mode(True)
+            ndex.host = None
+            try:
+                ndex.get_network_aspect_as_cx2_stream('someid',
+                                                      aspect_name='sa')
+                self.fail('Expected exception')
+            except NDExError as ne:
+                self.assertTrue('Caught TypeError:' in str(ne))
+
+    def test_get_network_as_cx2_stream_error(self):
+        with requests_mock.mock() as m:
+            m.get(client.DEFAULT_SERVER + '/v3/networks/someid',
+                  status_code=500,
+                  json={'error': 'bye'},
+                  headers={'Content-Type': 'application/json'})
+            ndex = Ndex2(skip_version_check=True)
+            ndex.set_debug_mode(True)
+            try:
+                ndex.get_network_as_cx2_stream('someid')
+                self.fail('Expected exception')
+            except NDExError as ne:
+                self.assertEqual(str(ne),
+                                 'Caught 500 from server: {"error": "bye"}')
+
+    def test_get_network_as_cx2_stream_low_level_error(self):
+        with requests_mock.mock() as m:
+            m.get(client.DEFAULT_SERVER + '/v3/networks/someid',
+                  status_code=200,
+                  json={'error': 'bye'},
+                  headers={'Content-Type': 'application/json'})
+            ndex = Ndex2(skip_version_check=True)
+            ndex.set_debug_mode(True)
+
+            # here we do a hack break by setting host to
+            # None which will cause a TypeError
+            ndex.host = None
+            try:
+                ndex.get_network_as_cx2_stream('someid')
+                self.fail('Expected exception')
+            except NDExError as ne:
+                self.assertEqual(str(ne),
+                                 'Caught TypeError: unsupported operand type(s) '
+                                 'for +: \'NoneType\' and \'str\'')
+
+    def test_get_network_as_cx2_stream_success(self):
+        with requests_mock.mock() as m:
+            m.get(client.DEFAULT_SERVER + '/v3/networks/someid',
+                  status_code=200,
+                  json={'hi': 'bye'},
+                  headers={'Content-Type': 'application/json'})
+            ndex = Ndex2(skip_version_check=True)
+            ndex.set_debug_mode(True)
+            res = ndex.get_network_as_cx2_stream('someid')
+            self.assertEqual(res.json(), {'hi': 'bye'})
+            self.assertEqual(res.status_code, 200)
+
+    def test_get_network_as_cx2_stream_w_access_key_success(self):
+        with requests_mock.mock() as m:
+            a_key = 'b4487036-84cb-4764-b058-a2abeb034b76'
+            m.get(client.DEFAULT_SERVER +
+                  '/v3/networks/someid?accesskey=' + a_key,
+                  status_code=200,
+                  json={'hi': 'bye'},
+                  headers={'Content-Type': 'application/json'})
+            ndex = Ndex2(skip_version_check=True)
+            ndex.set_debug_mode(True)
+            res = ndex.get_network_as_cx2_stream('someid', access_key=a_key)
+            self.assertEqual(res.json(), {'hi': 'bye'})
+            self.assertEqual(res.status_code, 200)
+
     def test_get_neighborhood_as_cx_stream(self):
         with requests_mock.mock() as m:
             m.get(self.get_rest_admin_status_url(),
